pub struct AsyncPrefetchBuilder { /* private fields */ }Expand description
Builder for creating async prefetch datasets.
Implementations
Sourceimpl AsyncPrefetchBuilder
impl AsyncPrefetchBuilder
Sourcepub fn batch_size(self, size: usize) -> Self
pub fn batch_size(self, size: usize) -> Self
Sets the batch size (rows per batch).
Sourcepub fn prefetch_size(self, size: usize) -> Self
pub fn prefetch_size(self, size: usize) -> Self
Sets the prefetch buffer size (number of batches).
Sourcepub fn from_parquet(
self,
path: impl AsRef<Path>,
) -> Result<AsyncPrefetchDataset>
pub fn from_parquet( self, path: impl AsRef<Path>, ) -> Result<AsyncPrefetchDataset>
Builds an async prefetch dataset from a Parquet file.
Errors
Returns an error if the file cannot be opened.
Sourcepub fn from_source(self, source: Box<dyn DataSource>) -> AsyncPrefetchDataset
pub fn from_source(self, source: Box<dyn DataSource>) -> AsyncPrefetchDataset
Builds an async prefetch dataset from a data source.