SyncPrefetchDataset

Struct SyncPrefetchDataset 

pub struct SyncPrefetchDataset { /* private fields */ }
Synchronous wrapper for async prefetch that works with DataLoader.

This allows using async prefetch with the existing synchronous DataLoader API by blocking on the async operations internally.

Implementations

Source

impl SyncPrefetchDataset

pub fn new(dataset: AsyncPrefetchDataset, runtime: Handle) -> Self

Creates a new sync wrapper around an async prefetch dataset.

Arguments
  • dataset - The async dataset to wrap
  • runtime - Handle to the tokio runtime
pub fn schema(&self) -> SchemaRef

Returns the schema.

pub fn next_blocking(&mut self) -> Option<Result<RecordBatch>>

Gets the next batch, blocking if necessary.