pub fn create_backend(config: BackendConfig) -> Result<Box<dyn StorageBackend>>Expand description
Creates a storage backend from configuration.
Errors
Returns an error if the backend cannot be created.
pub fn create_backend(config: BackendConfig) -> Result<Box<dyn StorageBackend>>Creates a storage backend from configuration.
Returns an error if the backend cannot be created.