HttpBackend

Struct HttpBackend 

pub struct HttpBackend { /* private fields */ }
A read-only storage backend using HTTP/HTTPS.

This backend is designed for accessing publicly hosted datasets over HTTP/HTTPS. It supports range requests for efficient partial reads when the server supports them.

Limitations

  • Read-only: put and delete operations will return errors
  • list is not supported (HTTP doesn’t have directory listings)

Example

use alimentar::backend::{HttpBackend, StorageBackend};

let backend = HttpBackend::new("https://huggingface.co/datasets").unwrap();
let data = backend.get("squad/train.parquet").unwrap();

Implementations

Source

impl HttpBackend

pub fn new(base_url: impl Into<String>) -> Result<Self>

Creates a new HTTP backend with the given base URL.

Arguments
  • base_url - Base URL for all requests. Keys will be appended to this.
Errors

Returns an error if the HTTP client cannot be created.

pub fn with_timeout( base_url: impl Into<String>, timeout_secs: u64, ) -> Result<Self>

Creates a new HTTP backend with custom client configuration.

Arguments
  • base_url - Base URL for all requests
  • timeout_secs - Request timeout in seconds
Errors

Returns an error if the HTTP client cannot be created.

pub fn base_url(&self) -> &str

Returns the base URL.