pub struct RangeHttpBackend { /* private fields */ }Expand description
HTTP backend with support for partial/range requests.
This variant supports reading specific byte ranges, which is useful for large files when only a portion is needed.
Implementations