Module doctest

Module doctest 

Python doctest extraction and corpus management.

This module provides tools for extracting Python doctests from source files and converting them to Arrow/Parquet format for ML training data.

Structs

DocTest
A single extracted Python doctest.
DocTestCorpus
A corpus of extracted doctests from a Python source.
DocTestParser
Parser for extracting Python doctests from source files.

Functions

is_prose_continuation
Returns true if line looks like a continuation of a prose paragraph.