load_from_file_with_options

Function load_from_file_with_options 

pub fn load_from_file_with_options<P: AsRef<Path>>(
    path: P,
    options: &LoadOptions,
) -> Result<LoadedDataset>
Load dataset from a file path with decryption and verification options

Errors

Returns error if file reading, decryption, verification, or deserialization fails.