pub struct SigningKeyPair { /* private fields */ }Expand description
Signing key pair for creating signatures
Implementations
Sourceimpl SigningKeyPair
impl SigningKeyPair
Sourcepub fn from_bytes(secret_key: [u8; 32]) -> Self
pub fn from_bytes(secret_key: [u8; 32]) -> Self
Create a signing key pair from existing secret key bytes
Sourcepub fn public_key_bytes(&self) -> [u8; 32]
pub fn public_key_bytes(&self) -> [u8; 32]
Get the public key bytes for this key pair
Sourcepub fn secret_key_bytes(&self) -> [u8; 32]
pub fn secret_key_bytes(&self) -> [u8; 32]
Get the secret key bytes