pub struct MemorySource { /* private fields */ }Expand description
A data source backed by in-memory RecordBatches.
Useful for testing or when you have data already in memory but want to use the streaming interface.
Implementations
Sourceimpl MemorySource
impl MemorySource