pub struct Filter<F>{ /* private fields */ }Expand description
A transform that filters rows based on a predicate.
The predicate function receives a RecordBatch and must return a BooleanArray
with the same number of rows, where true indicates the row should be kept.
Example
ⓘ
use alimentar::Filter;
use arrow::array::{Int32Array, BooleanArray};
let filter = Filter::new(|batch| {
let col = batch.column(0).as_any().downcast_ref::<Int32Array>().unwrap();
let mask: Vec<bool> = (0..col.len()).map(|i| col.value(i) > 5).collect();
Ok(BooleanArray::from(mask))
});Implementations