DatasetViewer

Struct DatasetViewer 

pub struct DatasetViewer { /* private fields */ }
A scrollable table view for displaying Arrow datasets

The viewer provides:

  • Scrollable rows with keyboard navigation
  • Column headers with field names
  • Selected row highlighting
  • Automatic column width calculation
  • Truncation with ellipsis for long values

Example

let adapter = DatasetAdapter::from_dataset(&dataset)?;
let viewer = DatasetViewer::new(adapter);

// Handle keyboard input
viewer.scroll_down();
viewer.select_row(5);

// Get visible data for rendering
let headers = viewer.headers();
let rows = viewer.visible_rows();

Implementations

Source

impl DatasetViewer

pub fn new(adapter: DatasetAdapter) -> Self

Create a new viewer with default dimensions

Arguments
  • adapter - The dataset adapter to display
pub fn with_dimensions(adapter: DatasetAdapter, width: u16, height: u16) -> Self

Create a new viewer with specific dimensions

Arguments
  • adapter - The dataset adapter to display
  • width - Display width in characters
  • height - Display height in rows (including header)
pub fn set_dimensions(&mut self, width: u16, height: u16)

Update display dimensions

Recalculates column widths and scroll state.

pub fn scroll_offset(&self) -> usize

Get the current scroll offset

pub fn set_scroll_offset(&mut self, offset: usize)

Set the scroll offset

pub fn row_count(&self) -> usize

Get total row count

pub fn visible_row_count(&self) -> u16

Get visible row count

pub fn selected_row(&self) -> Option<usize>

Get the currently selected row

pub fn select_row(&mut self, row: usize)

Select a specific row

pub fn clear_selection(&mut self)

Clear selection

pub fn is_empty(&self) -> bool

Check if the dataset is empty

pub fn adapter(&self) -> &DatasetAdapter

Get the adapter reference

pub fn column_widths(&self) -> &[u16]

Get column widths

pub fn scroll_down(&mut self)

Scroll down by one row

pub fn scroll_up(&mut self)

Scroll up by one row

pub fn page_down(&mut self)

Scroll down by one page

pub fn page_up(&mut self)

Scroll up by one page

pub fn home(&mut self)

Jump to first row

pub fn end(&mut self)

Jump to last page

pub fn select_next(&mut self)

Select next row

pub fn select_prev(&mut self)

Select previous row

pub fn headers(&self) -> Vec<String>

Get column headers

pub fn visible_rows_data(&self) -> Vec<Vec<String>>

Get visible rows as formatted strings

Returns a vector of rows, where each row is a vector of cell strings.

pub fn is_row_selected(&self, global_row: usize) -> bool

Check if a row is currently selected

pub fn needs_scrollbar(&self) -> bool

Check if scrollbar should be shown

pub fn scrollbar_position(&self) -> f32

Get scrollbar position (0.0 to 1.0)

pub fn scrollbar_size(&self) -> f32

Get scrollbar size (0.0 to 1.0)

pub fn render_header_line(&self) -> String

Render header line as a string

pub fn render_row_line(&self, viewport_row: usize) -> Option<String>

Render a data row as a string

pub fn viewport_to_data_row(&self, viewport_row: usize) -> usize

Get the data row index for a viewport row

pub fn search(&mut self, query: &str) -> Option<usize>

Search for a substring and select the first matching row

Returns the row index if found, None otherwise. This is a linear scan suitable for datasets <100k rows (F101).

pub fn search_next(&mut self, query: &str) -> Option<usize>

Continue search from current position

Wraps around to beginning if no match found after current row.

pub fn render_lines(&self) -> Vec<String>

Render complete output as lines

Returns header followed by visible data rows.