pub struct SyncPrefetchDataset { /* private fields */ }Expand description
Synchronous wrapper for async prefetch that works with DataLoader.
This allows using async prefetch with the existing synchronous DataLoader API by blocking on the async operations internally.
Implementations
Sourceimpl SyncPrefetchDataset
impl SyncPrefetchDataset
Sourcepub fn new(dataset: AsyncPrefetchDataset, runtime: Handle) -> Self
pub fn new(dataset: AsyncPrefetchDataset, runtime: Handle) -> Self
Creates a new sync wrapper around an async prefetch dataset.
Arguments
dataset- The async dataset to wrapruntime- Handle to the tokio runtime
Sourcepub fn next_blocking(&mut self) -> Option<Result<RecordBatch>>
pub fn next_blocking(&mut self) -> Option<Result<RecordBatch>>
Gets the next batch, blocking if necessary.