pub struct HttpBackend { /* private fields */ }Expand description
A read-only storage backend using HTTP/HTTPS.
This backend is designed for accessing publicly hosted datasets over HTTP/HTTPS. It supports range requests for efficient partial reads when the server supports them.
Limitations
- Read-only:
putanddeleteoperations will return errors listis not supported (HTTP doesn’t have directory listings)
Example
use alimentar::backend::{HttpBackend, StorageBackend};
let backend = HttpBackend::new("https://huggingface.co/datasets").unwrap();
let data = backend.get("squad/train.parquet").unwrap();Implementations