pub struct MnistDataset { /* private fields */ }Expand description
MNIST handwritten digits dataset
Implementations
Sourceimpl MnistDataset
impl MnistDataset
Sourcepub fn load_full() -> Result<Self>
pub fn load_full() -> Result<Self>
Load full MNIST from HuggingFace Hub (requires hf-hub feature)
Sourcepub fn split(&self) -> Result<DatasetSplit>
pub fn split(&self) -> Result<DatasetSplit>
Get stratified train/test split (80/20 for embedded data)
Uses stratified sampling to ensure all digit classes (0-9) are represented in both train and test sets with proportional distribution.
Errors
Returns an error if the dataset is empty or split fails.